@@ -455,7 +455,7 @@ impl ClientInternal {
         log::debug!("client.SendBindingRequestTo call PerformTransaction 1");
         let tr_res = self.perform_transaction(&msg, to, false).await?;
 
-        let mut refl_addr = XORMappedAddress::default();
+        let mut refl_addr = XorMappedAddress::default();
         refl_addr.get_from(&tr_res.msg)?;
 
         Ok(SocketAddr::new(refl_addr.ip, refl_addr.port))
@@ -478,11 +478,7 @@ impl ClientInternal {
         ch_num: u16,
     ) -> Option<SocketAddr> {
         let bm = binding_mgr.lock().await;
-        if let Some(b) = bm.find_by_number(ch_num) {
-            Some(b.addr)
-        } else {
-            None
-        }
+        bm.find_by_number(ch_num).map(|b| b.addr)
     }
 
     // Allocate sends a TURN allocation request to the given transport address
